{% extends "ishtar/merge.html" %}
{% load url from future %}
{% block merge_field_row %}
      {% if form.non_field_errors %}<tr><td colspan='4'></td><td colspan='3' class='errorlist'>{% for error in form.non_field_errors %}{{error}} {% endfor%}</tr>{% endif %}
      <tr>
        <td>
          <a href="#" onclick="load_window('{% url 'show-organization' form.instance.from_organization.pk '' %}', 'organization');" class="display_details"><i class="fa fa-info-circle" aria-hidden="true"></i></a>
        </td>
        <td>
          {{form.instance.from_organization}} ({{form.instance.from_organization.pk}})<br />
          {{form.instance.from_organization.address_lbl|linebreaksbr}}
        </td>
        <td>
          <a href="#" onclick="load_window('{% url 'show-organization' form.instance.to_organization.pk '' %}', 'organization');" class="display_details"><i class="fa fa-info-circle" aria-hidden="true"></i></a>
        </td>
        <td>
          {{form.instance.to_organization}} ({{form.instance.to_organization.pk}})<br />
          {{form.instance.to_organization.address_lbl|linebreaksbr}}
        </td>
        <td class='check'>{{form.b_is_duplicate_a}}</td>
        <td class='check'>{{form.a_is_duplicate_b}}</td>
        <td class='check'>{{form.not_duplicate}}</td>
      </tr>
{% endblock %}

