{% extends "base.html" %}
{% load i18n %}

{% block content %}
<div class='info'>
<p>{% trans "Password reset successfully" %}</p>

<p><a href="{% url auth_login %}">{% trans "Log in" %}</a></p>
</div>
{% endblock %}
