{% load i18n %}{% if data.count %}{% if li %}<li>{% else %}<p>{% endif %}<label>{% trans caption %}{% trans ":"%}</label>
    <span class='value'>{% for d in data.all %}
        {% if forloop.counter0 %} ; {% endif %}{{ d }}
    {% endfor %}</span>
{% if li %}</li>{% else %}</p>{% endif %}
{% endif %}
