{% load i18n %}
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

<head>
    <link rel="shortcut icon" href="{{STATIC_URL}}/media/images/favicon.png">
    <title>{% block title %}Ishtar{% if APP_NAME %} - {{APP_NAME}}{%endif%}{% endblock %}
    </title>
    <script language="javascript" type="text/javascript">
        var url_path = "{{URL_PATH}}";
    </script>
    <script language="javascript" type="text/javascript" src="{{JQUERY_URL}}?ver={{VERSION}}"></script>
    <script language="javascript" type="text/javascript" src="{{JQUERY_UI_URL}}jquery-ui.js?ver={{VERSION}}"></script>
    <script language="javascript" type="text/javascript" src="{{JQUERY_UI_URL}}ui/i18n/jquery.ui.datepicker-{{COUNTRY}}.js?ver={{VERSION}}"></script>
    <script language="javascript" type="text/javascript" src="{{STATIC_URL}}js/chosen/chosen.jquery.min.js?ver={{VERSION}}"></script>
    <script language="javascript" type="text/javascript" src="{{STATIC_URL}}js/ishtar.js?ver={{VERSION}}"></script>
    {{form.media}}
    <link type="text/css" href="{{JQUERY_UI_URL}}jquery-ui.css?ver={{VERSION}}" rel="stylesheet" />
    <link type="text/css" href="{{STATIC_URL}}js/chosen/chosen.min.css?ver={{VERSION}}" rel="stylesheet" />
    <link rel="stylesheet" href="{{STATIC_URL}}media/style.css?ver={{VERSION}}" />
    {% block extra_head %}
    {% endblock %}
</head>
<body>
{% if new_item_label %}
<script type='text/javascript' language='javascript'>
save_and_close_window{% if many %}_many{% endif %}("{{parent_name}}", "{{parent_pk}}", "{{new_item_label|safe}}", "{{new_item_pk}}");
</script>
{% endif %}
<div id="window_content">
  <h3>{{title}}</h3>
  <form action="." method="post" class='form'>{% csrf_token %}
    <table>
    {% for field in form %}
    <tr{% if field.field.required %} class='required'{% endif %}>
      <th>{{ field.label_tag }}</th>
      <td>{{ field.errors }}{{field|safe}}</td>
    </tr>{% endfor %}
    <tr><td colspan='2' class='submit_button'><input type="submit" id="submit_new_item" value="{% trans "Add" %}"/></td></tr>
    </table>
  </form>
  </div>

</div>
</body>

</html>
