@page {
  size: a4 portrait;
  margin: 2.5cm 1cm 2.5cm 1cm;
  background-image: url("images/ishtar-bg.jpg");
  @frame footer {
    -pdf-frame-content: pdffooter;
    bottom: 1cm;
    margin-left: 1cm;
    margin-right: 1cm;
    height: 1cm;
  }
  @frame header {
    -pdf-frame-content: pdfheader;
    top: 1.2cm;
    margin-left: 1cm;
    margin-right: 1cm;
    height: 1.5cm;
  }
}

label{
    display:inline;
    font-weight:bold;
}

table{
    margin:10px;
    width:100%;
    border: none;
    border-collapse:collapse;
}

caption, h3{
    display:block;
    text-align:center;
    font-size:1.5em;
}

th{
    text-align:center;
    border-bottom:2px solid #922;
}

td{
    margin:0;
    padding:0;
    padding-top:4px;
    text-align:right;
    border:1px solid #EEE;
    border-top:none;
    font-size:0.9em;
}

.link{
    display:None;
}

.string{
    text-align:left;
}

.no_items{
    text-align:center;
    font-style:italic;
}

.head{
    display:none;
}

.tool{
    display:none;
}

p{
    margin:0.2em;
}

#pdffooter, #pdfheader{
    text-align:center;
}

#pdfheader{
    font-weight:bold;
    width:100%;
    border-bottom:1px solid #922;
}

.display_details, .display_details_inline{
    display: none;
}
