{% extends "base.html" %}
{% load i18n %}
{% load url from future %}
{% block content %}
<h2>{{page_name}}</h2>
<script type='text/javascript'>
$(function() {
    load_window("{% url item_url pk %}");
});
</script>
{% endblock %}
