{% load i18n %}
<h4>{{caption}}</h4>
<div class='clean-table'>
<div class='clean-table-wrap'>
<table>
  <caption>{{caption}}</caption>
  <tr>{% for col in col_names %}
    <th>{% trans col %}</th>{% endfor %}
  </tr>{% for item in data %}
  <tr>{% for value in item %}
    <td>{{value}}</td>{%endfor%}
  </tr>{% endfor %}
</table>
</div></div>
