{% extends "ishtar/wizard/wizard_done.html" %}
{% load i18n %}
{% block content %}

<div class='form'>
  <p>{% trans {%trans "Item successfully saved"%} %}</p>	
  <p>{% trans "You have saved the following informations:" %}</p>
  <p>{% trans {%trans "The file must be processed before :"%} %} {% calculated_deadline %}  </p>
  <p>{% trans {%trans "The person in charge is : "%} %} {% responsible %} </p>
  <p>{% trans {%trans "The internal reference of this file is :"%} %} {% Year %} - {% ref_index %} [{% ref_string %}]</p>

  {% for form_label, form_data in datas %}
  <table class='confirm'>
    <caption>{{form_label}}</caption>
    {% for label, data, cls in form_data %}
    <tr{%if cls%} class='{{cls}}'{%endif%}><th>{{label}}</th><td>{{data}}</td></th>
    {% endfor %}
  </table>
  {% endfor %}

</div>

{% endblock %}
