div#validation-bar{
    position: fixed;
    bottom: 0px;
    background-color: #CCC;
    width: 100%;
    left: 0px;
    height: 40px;
    padding: 5px;
    z-index: 101;
}

#reset_wizards{
    right:50px;
    position:absolute;
}
