{% extends "ishtar/wizard/default_wizard.html" %}
{% load i18n range table_form %}
{% block wizard_form %}
<script type='text/javascript'>
function update_form(){
    if ($('input[name="person_type"]:radio:checked').val() == 'corporation'){
        $('#natural_div').hide();
        $('#corporation_div').show();
        $('#orga-form').show();
    } else {
        $('#natural_div').show();
        $('#corporation_div').hide();
        $('#orga-form').hide();
    }
}
$(function() {
    update_form();
});
</script>
<form action="." method="post" name='wizard'{% if wizard.form.file_upload %} enctype="multipart/form-data"{% endif %}>{% csrf_token %}
<div class='form'>
{% if wizard.form.media %}{{ wizard.form.media }}{% endif %}
{{ wizard.management_form }}

<table class='formset'>
  <caption>Statut</caption>
  <tr>
    <th><label>{% trans "Corporation" %}</label></th>
    <td><input type='radio' name='person_type' value='corporation'/></td>
  </tr>
  <tr>
    <th><label>{% trans "Natural person" %}</label></th>
    <td><input type='radio' name='person_type' value='natural'/></td>
  </tr>
</table>

<table id='corporation_div'>
  {% if wizard.form.non_field_errors %}<tr class='errors'>
    <td colspan='3'>{{wizard.form.non_field_errors}}</td>
  </tr>{%endif%}

{% block corporation %}
{% endblock %}
</table>
<div id='natural_div'>
<table>
  {% if wizard.form.non_field_errors %}<tr class='errors'>
    <td colspan='3'>{{wizard.form.non_field_errors}}</td>
  </tr>{%endif%}

{% block natural %}
{% endblock %}
</table>
</div>

<div>
{% block otherfields %}
{% endblock %}
</div>
{% block extra_head_po %}
{% endblock %}

<input type="hidden" name="{{ step_field }}" value="{{ step0 }}" />
{{ previous_fields|safe }}
{% block "validation_bar" %}
{% include 'ishtar/wizard/validation_bar.html' %}
{% endblock %}
</div>
</form>
{% endblock %}

