{% extends "ishtar/sheet.html" %}
{% load i18n window_field link_to_window %}

{% block content %}
{% block window_nav %}{% endblock %}
{% block general %}
{% block related %}
{% field "Related item" item.owner %}
{% endblock %}

{% if item.image %}
<a href='{{item.image.url}}' rel="prettyPhoto" title="{{item.label}}" class='photo'><img src='{{item.thumbnail.url}}'/></a>
{% endif%}

<ul class='form-flex'>
{% field_li "Title" item.title %}
{% field_li "Index" item.index %}
{% field_li "Source type" item.source_type %}
{% field_li "Format type" item.format_type %}
{% field_li "Scale" item.scale %}
{% field_li_url "Web link" item.associated_url %}
{% field_li "Item number" item.item_number %}
{% field_li "Ref." item.reference %}
{% field_li "Internal ref." item.internal_reference %}
{% field_li "Creation date" item.creation_date %}
{% field_li "Receipt date" item.receipt_date %}
{% field_li "Receipt date in documentation" item.receipt_date_in_documentation %}
{% field_li "Has a duplicate" item.duplicate %}
{% field_li "Description" item.description %}
{% field_li "Comment" item.comment %}
{% field_li "Additional information" item.additional_information %}
</ul>
{% field "Authors" item.authors|add_links:'person' %}
{% endblock %}
{% endblock %}

