{% extends "base.html" %}
{% load i18n %}
{% block content %}
<p>{%trans "Item successfully saved"%}</p>
{% if redirect or wizard_done_window %}
<script type='text/javascript' language='javascript'>
{% if redirect %}
window.location.href = "{{redirect}}";
{% endif %}
{% if wizard_done_window %}
$(function(){ load_window("{{wizard_done_window}}{{item.pk}}/"); });
{% endif %}
</script>
{% endif %}
{% endblock %}
