/* background color */
.ui-widget-content .ui-state-highlight{
    background-color:#ff6e6e;
}

a.remove,
#progress-content{
    background-color:#fff;
}

div.form, ul.form {
    background-color: #f1f2f6;
}

#window h1{
    background-color: #922;
}

.badge, a.add-button, #reset_wizards{
    background-color: #D14;
}

/* color  */

.pin-action,
#window hr,
#context_menu .red,
a, a.remove {
    color:#D14;
}

span.disabled,
a.disabled {
    color:#ccc;
}

span.disabled:hover,
a.disabled:hover {
    color:#DB5C7C;
}

.badge,
a.add-button,
#reset_wizards,
#window h1{
    color:#fff;
}

#context_menu .orange {
    color:#dd6011;
}

#context_menu .green {
    color:#13ae0c;
}

#context_menu .normal{
    color:#000;
}

.chosen-container,
#context_menu .green,
#context_menu .red,
#context_menu .orange,
#context_menu .basket{
    font-family: 'FontAwesome', Arial, Helvetica, sans-serif;
}

#context_menu .chosen-select{
    width: 400px;
}

#context_menu option.basket{
    color:#000;
}

/* borders */
a.add-button, a.remove,
#progress-content,
div.form {
    border:0 solid #CCC;
}

#window hr{
    border:0;
    border-bottom:1px solid #D14;
}

hr.spacer{
    clear:both;
    border:0;
    margin: 13px;
}

#window hr.clear,
hr.clear{
    clear: both;
    border: 0 solid transparent;
    height: 0;
    margin: 0;
}

.fa-stack-15x {
    position: absolute;
    left: 0;
    width: 100%;
    text-align: center;
    font-size: 1.5em;
    line-height: 1.4em;
}

.badge{
    border: 1px solid #D14;
}

.close-buttons{
    position: absolute;
    right: 10px;
    top: 2px;
}

/* shadows */
#progress-content,
.sheet{
    -webkit-box-shadow: 0px 0px 20px #444;
    -moz-box-shadow: 0px 0px 20px #444;
    box-shadow: 0px 0px 20px #444;
}

/* radius */
a.button,
a.add-button, a.remove {
    -moz-border-radius:4px;
    -webkit-border-radius:4px;
    border-radius:4px;
}

.sheet,
#progress-content,
div.form {
    -moz-border-radius: 0;
    -webkit-border-radius: 0;
    border-radius: 0;
}

body{
    font-family: Arial, Helvetica, sans-serif;
    font-size: 11pt;
    margin:0;
    color:#61615C;
    background-image:url(images/ishtar-bg.jpg);
    background-repeat:no-repeat;
    background-position:right 90px;
}

a {
    text-decoration:none;
}

caption, h2, h3, #window h4 {
    color:#922;
    font-weight:bold;
}

h2{
    margin:0;
    font-size:1.2em;
}

h3{
    text-align:center;
    margin:1em 0 0.5em 0;
}

#window h4 {
    text-align: center;
}

h4{
    margin:10px 0;
}

pre {
    padding: 0.5em 1em;
    white-space: pre-wrap;
    white-space: -moz-pre-wrap;
    white-space: -pre-wrap;
    white-space: -o-pre-wrap;
}

select{
    max-width:550px;
}

/*label{display:block}*/

label:first-letter {
  text-transform: uppercase;
}

textarea{
    height:80px;
}

textarea.xlarge{
    height: 450px;
    width: 450px;
}

dt{
    font-weight:bold;
    color:#922;
    padding:1em;
}

td{
    text-align:left;
}

div.selected{
    border:1px solid #922;
}

textarea:disabled,
input[type="text"]:disabled{
    background-color: #eee;
}

button{
    background-color:#f1f2f6;
    border:1px solid #AAA;
    color:#444;
}

button, input[type=submit], button.submit{
    background-color:#FFF;
    border:1px solid #FFF;
    margin:6px;
    font-size:0.9em;
    padding:4px 8px;
    border-radius:4px;
    -moz-border-radius:4px;
    -webkit-border-radius:4px;
}

button.btn-selected,
button:hover, input[type=submit]:hover{
    cursor:pointer;
    color:#922;
    border:1px solid #922;
}

button.ui-widget-header {
    font-weight: normal;
    border:1px solid #f8b950;
    background: #f8b950;
}

button.ui-widget-header:hover {
    color:#fff;
    border:1px solid #f8b950;
    background: #f8b950;
}

#ui-datepicker-div{
    z-index: 100  !important;
}

.chosen-container-active.chosen-with-drop .chosen-single,
.chosen-container-single .chosen-single{
    background: none;
    background-color: #fff;
    border-radius:4px;
}

textarea,
input[type=text],
input[type=password],
input[role=textbox]{
    background-color:#FFF;
    border:1px solid #FFF;
    border-radius:4px;
    -moz-border-radius:4px;
    -webkit-border-radius:4px;
}

textarea[readonly=readonly],
input[readonly=readonly]{
    background-color:#F1F2F6;
    border:1px solid #F1F2F6;
}


textarea:focus,
input[type=text]:focus,
input[type=password]:focus,
input[role=textbox]:focus{
    border:1px solid #D14;
}

ul.form-flex.hidden, .hidden{
    display:none;
}

ul.list{
    text-align:left;
    line-height:16px;
}

div.nav-button{
    cursor:pointer;
    width:15px;
    z-index:1000;
    position:fixed;
    right:32px;
    font-size: 40px;
    background-color: transparent;
    border: 0 solid transparent;
}

#message,
#message div{
    display: none;
}

#message {
    z-index: 42200;
    position: absolute;
    top: 5px;
    right: 5px;
    background: #fff;
    padding: 0.5em 1em;
    border: 1px solid;
    border-radius: 3px;
}

#message span{
    padding: 0 1em;
}

#to_bottom_arrow{
    bottom:80px;
}

#to_top_arrow{
    top:160px;
}

div#header{
    width:100%;
    text-align:left;
    font-size: 0.9em;
    background-color: #CCC;
    margin-bottom:10px;
    line-height:30px;
    padding:0 20px;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
}

#logo{
    display: block;
    width:200px;
    top:40px;
    left:10px;
    padding-top:90px;
    position:absolute;
    text-align:center;
    background-image:url(images/ishtar-text.png);
    background-repeat:no-repeat;
}

div#validation-bar p{
    margin:0;
}

div#validation-bar input{
    margin:0 30px;
}

div#validation-bar.big{
    height:60px;
}

a.button{
    padding: 8px;
}

#reset_wizards{
    color: white;
}

.display_details_inline,
.display_details{
    display:inline-block;
    font-size:18px;
    width:18px;
    height:16px;
    text-decoration:none;
    vertical-align: bottom;
}

.display_details_inline{
    display:inline;
    padding:13px;
}

div#language_form_div{
    position:absolute;
    right:0;
    top:0;
    padding:2px 20px;
}

#language_selector{
    border-radius: 0;
    background-color: #fff;
    border-width: 0;
}

/*
div#language_form_div label{
    display:inline;
}*/

.btn-group .btn{
    padding: 0;
    margin: 0;
}

.short-menu-buttons{
    position: absolute;
    margin-top: -20px;
}

div#context_menu{
    height:110px;
    margin-right:10px;
    z-index: 1000;
    position: absolute;
    right: 0;
}

div#context_menu fieldset{
    margin-top: 8px;
    background-color:#f1f2f6;
    border:0 solid #CCC;
    -moz-border-radius: 0;
    -webkit-border-radius: 0;
    border-radius: 0;
}

div#action_current_items{
    display: inline-block;
    vertical-align: top;
    width: 70px;
}

div#action_current_items p{
    padding: 0;
    margin: 0;
    text-align: center;
}

div#context_menu table{
    display: inline;
    vertical-align: top;
}

div#context_menu .icon{
    padding: 0.2em 0.3em;
}

div#context_menu ul{
    margin:0;
    padding:2px;
}

div#context_menu li{
    margin: 0;
    list-style:none;
}

div#main_menu{
    width:200px;
    top:160px;
    position:absolute;
}

div#main_menu ul{
    padding-left:0.8em;
    cursor:pointer;
    list-style:none;
}

div#main_menu a{
    color:#666;
}

div#main_menu a:hover{
    color:#D14;
}

div#main_menu .selected a{
    color:#D14;
}

div#main_menu > ul{
    color:#922;
}

div#main_menu > ul > li{
    padding:0.5em;
    margin:0 0.5em;
    border-radius:0;
    -moz-border-radius:0;
    -webkit-border-radius:0;
}

#section-file_management,
#section-administrativact_management{
    background-color:#ddffdd;
}

#subsection-admin_act_operations{
    background-color:#f0fff0;
}

/*
#section-1, #theme-1 div.form{
    background-color:#ccccff;
}

#section-2, #theme-2 div.form{
    background-color:#ccffcc;
}

#section-3, #theme-3 div.form{
    background-color:#ffffcc;
}

#section-4, #theme-4 div.form{
    background-color:#ffcccc;
}

#section-5, #theme-5 div.form{
    background-color:#decfad;
}

#section-6, #theme-6 div.form{
    background-color:#ffcc99;
}

#section-7, #theme-7 div.form{
    background-color:#ccc;
}
*/

div#welcome{
    text-align:left;
    font-size: 1.2em;
}

div#content{
    clear:both;
    margin-top:190px ;
    margin-bottom: 70px;
    margin-left: 200px;
    margin-right: 150px;
    text-align:center;
}

@media screen and (max-width: 1050px) {
    div#content{
        margin-right:0px;
    }
}

ul#form_path, ul#form_path li{
    list-style-type:none;
    padding:0;
    margin:0;
}

ul#form_path{
    border:1px solid #dedede;
    /*height:2.3em;*/
    background-color:#fff;
    margin-bottom:10px;
    text-align:left;
}


ul#form_path li {
    display:inline-block;
    line-height:2.3em;
    padding-left:.75em;
    color:#777;
}

ul#form_path li a, ul#form_path li button{
    display:inline-block;
    padding:0 15px 0 0;
    background:url(images/crumbs.gif) no-repeat right center;
}

ul#form_path li button{
    height:33px;
    padding:0;
    margin:0;
    padding-right:10px;
    border:0 solid #fff;
}

ul#form_path li button:hover{
    color:#D14;
    border:0 solid #fff;
}


ul#form_path li a:link, ul#form_path li a:visited {
    text-decoration:none;
    color:#922;
}

#reminder{
    padding:0.4em;
    margin-right:10px;
    border:1px solid #CCC;
    -moz-border-radius:0;
    -webkit-border-radius:0;
    border-radius:0;
    background-color:white;
    position: absolute;
    z-index:1000;
    left: 200px;
}

#reminder p{
    margin:0;
    padding:0;
}

#reminder strong.lbl,
#reminder span.value {
    display:inline-block;
    max-width:250px;
    vertical-align:top;
}

div.form {
    margin-left:auto;
    margin-right:auto;
    margin-bottom:40px;
    padding:20px;
    display:block;
    text-align:center;
}

ul.form-flex {
    list-style-type: none;
    text-align: left;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: -moz-flex;
    display: flex;
    -webkit-flex-wrap: wrap;
    -ms-flex-wrap: wrap;
    -moz-flex-wrap: wrap;
    flex-wrap: wrap;
    width: 400px;
    padding: 0;
    margin: 0;
}

ul.form-flex li{
    width: 395px;
    padding-top: 0.3em;
}

@media screen and (min-width: 1051px) {
    div.form,
    ul.form-flex{
        width: 800px;
    }
}

@media screen and (min-width: 1400px) {
    div.form,
    ul.form-flex{
        width: 1200px;
    }
}

ul.form-flex label {
    display: inline-block;
    width: 150px;
    padding-left: 10px;
}

ul.form-flex li li label {
    width: 300px;
}

#window ul.form-flex label {
    width: 150px;
}

.form table{
    padding:0.2em;
    margin-left:auto;
    margin-right:auto;
    background-color:#F1F2F6;
    min-width: 600px;
}

.form table th{
    text-align:left;
    width:200px;
    font-weight:normal;
}

.form td ul{
    list-style:none;
}

.form .errorlist{
    color:#922;
}

.form .required label{
    font-weight:bold;
}

.form p.input{
    display: inline-block;
    width: 200px;
    margin: 5px;
}

.form p.input input{
    width: 200px;
}

.form p.input select{
    width: 200px;
}

.form input[readonly=True]{
    background-color:#f1f2f6;
    border:0;
}

.form .item-list{
    text-align:left;
}

.help_text{
    display:none;
    font-size:0.9em;
}

ul.form .help_text{
    width: 400px;
}

.help_text div{
    background-color:#FFF;
    margin:1em;;
    padding:0 1em;
    -moz-border-radius:8px;
    -webkit-border-radius:8px;
    border-radius:8px;
    border:1px solid #fff;
}

.help_text .example{
    font-style:italic;
}

.info{
    margin-left:auto;
    margin-right:auto;
    padding:1em;
    display:block;
    width:740px;
}

.info p{
    padding:0;
    margin:0.2em;
}

.badge{
    padding: 0.1em 0.3em;
    border-radius: 1em;
    line-height: 1.8em;
    font-style: normal;
}

.pin-action:hover{
    cursor:pointer;
}

.autocomplete{
    width:350px;
}

.delete td{
    text-align:center;
    border-bottom:1px solid #CCC;
    padding:6px;
}

.modify td, .submit td{
    text-align:center;
}

div.form table.confirm{
    padding:0.5em 2em;
    margin-left:0;
    width:100%;
}

table.confirm tr.spacer td:last-child{
    border-bottom:1px solid #922;
}

/* jquery widget customizations */

.ui-autocomplete{
    font-size:0.7em;
    z-index:10000 !important;
    width:350px;
}

.ui-autocomplete-loading {
    background:url('images/indicator.gif') no-repeat right center;
}

.gridfooter{
    text-align: center;
    font-style: italic;
}

.jqgrid{
    cursor:pointer;
}

.ui-jqgrid a{
    color:red;
    text-decoration:underline;
    color:#D14;
}

.ui-widget-content .ui-state-highlight{
    background-image:none;
}

.ui-tabs .ui-tabs-nav li a{
    color: #D14;
}

.ui-state-default, .ui-widget-content .ui-state-default, .ui-widget-header .ui-state-default {
    background:none;
    background-color: #F1F2F6;
    border: 1px solid #CCC;
    border-radius-top: 4px;
}

.ui-tabs .ui-tabs-nav li.ui-tabs-active a{
    background-color:#fff;
    color:#666;
}

.sheet{
    width:90%;
    position:fixed;
    height:90%;
    background: #FFF;
    z-index: 2000;
    /*left: 50%;*/
    margin-left: 5%;
    -webkit-box-shadow: 0px 0px 20px #444;
    -moz-box-shadow: 0px 0px 20px #444;
    text-align: left;
    display:none;
    -moz-border-radius:8px;
    -webkit-border-radius:8px;
    border-radius:8px;
}

.previous_page, .next_page{
    position:absolute;
    top:2px;
    color: #000;
    z-index: 1000;
}

.previous_page{
    left:95px;
}

.next_page{
    right:95px;
}

a.photo{
    padding: 0.5em;
}

#global-vars textarea{
    width:220px;
}

#global-vars input[type=text]{
    width:160px;
}

#dashboard{
    padding-top: 20px;
}

#dash-tabs .ui-tabs .ui-tabs-panel{
    padding:0;
}

.dashboard{
    margin-top: 1em;
}

.dashboard.ui-accordion .ui-accordion-header{
    margin-left: auto;
    margin-right: auto;
    padding-top: 0.8em;
    padding-bottom: 0.8em;
}

.dashboard.ui-accordion .ui-accordion-content{
    padding: 1.3em;
}

.dashboard .ui-icon,
.dashboard .ui-state-hover .ui-icon,
.dashboard .ui-state-default .ui-icon,
.dashboard .ui-state-active .ui-icon {
    background-image: none;
    color: white;
    text-indent: 0;
}

.dashboard .ui-state-active .ui-icon:before {
    content: "\f0d7";
    font-family: 'FontAwesome';
}

.dashboard .ui-icon:before {
    content: "\f0da";
    font-family: 'FontAwesome';
}

.dashboard > div,
.dashboard h3{
    width:760px;
    margin:0;
    margin-left:auto;
    margin-right:auto;
    border-radius: 4px;
}

.dashboard > div{
    background: #FFF;
    text-align:left;
    padding:10px;
    border:1px solid #CCC;
    border-top-left-radius: 0;
    border-top-right-radius: 0;
}

.dashboard h3{
    margin-top:1em;
    background-color:#922;
    color:#FFF;
    padding:10px;
}

.dashboard p{
    margin:0;
    padding:0 10px;
}

.dashboard div.form{
    padding:20px 10px;
    width:740px;
}

.dashboard select {
    max-width: 400px;
}

#window .table, .dashboard .table{
    padding:10px;
    width:730px;
    overflow:auto;
}

#window table.simple, .dashboard table.resume{
    font-size:0.9em;
    margin:10px 0;
    padding: 0 10px;
    border-collapse:collapse;
    width:100%;
}

#window caption, .dashboard caption{
    font-size:1.2em;
}

.dashboard caption{
    text-align:left;
    padding:0.5em 1em;
}

.chart-img{
    display:none;
}

.chart-img-form{
    margin-top:1em;
}

#window table.simple th, .dashboard table.resume th{
    background-color:#922;
    border:1px solid #f1f2f6;
    color:#FFF;
}

#window table.simple th{
    text-align:center;
}

#window a img{
    display:block;
    margin-left:auto;
    margin-right:auto;
}

.welcome-image{
    padding: 1em;
    text-align: center;
}

.dashboard table.resume th{
    text-align:center;
    padding:0.5em;
}

#window table th.sub, .dashboard table.resume th.sub, .dashboard table.resume td.sub{
    background-color:#994242;
    border:1px solid #f1f2f6;
    color:#FFF;
    padding:0 1em;
}

#window table.resume th.sub, .dashboard table.resume th.sub{
    text-align:left;
}

#window table.simple td, .dashboard table.resume td{
    text-align:right;
    padding:0 1em;
    border:1px solid #f1f2f6;
}

#window table td.ref, .dashboard table.resume td.ref{
    text-align:left;
    white-space:nowrap;
    font-family:monospace;
    font-size:9pt;
}

#window table td.no_items{
    text-align:center;
    font-style:italic;
}

#window table.simple td.item-list{
    text-align:left;
}

table td.item-list span{
    padding: 4px 4px;
    background-color: #eee;
    margin: 0.2em;
    line-height: 26px;
    border-radius: 4px;
}

#window table.simple td.item-list .display_details{
    vertical-align: middle;
}

#window .head{
    text-align:center;
    background-color:#f1f2f6;
}

#window .tool-left,
#window .tool-right,
#window .tool{
    text-align:center;
    font-style:italic;
}

#window .tool-right{
    float: right;
    padding: 0 2em;
}

#window .tool-left{
    float: left;
    padding: 0 2em;
}

#window .tool.modify{
    font-style:normal;
    font-weight:bold;
}

.history-nav{
    display: inline-block;
    width: 100px;
    vertical-align: top;
}

#window .body{
    position:absolute;
    padding:2px 10px 6px 10px;
    overflow:auto;
    top:38px;
    bottom:10px;
    width:100%;
    padding:0;
}

#window h1{
    text-align:center;
    font-size:16px;
    margin-top:0;
    padding: 0.2em;
}

#window .head, #window h1{
    -webkit-border-top-left-radius: 8px;
    -webkit-border-top-right-radius: 8px;
    -moz-border-radius-topleft: 8px;
    -moz-border-radius-topright: 8px;
    border-top-left-radius: 8px;
    border-top-right-radius: 8px;
}

.dashboard label,
#window label{
    display:inline-table;
    font-weight:bold;
    width:245px;
}

.dashboard span.value,
#window span.value{
    display:inline-table;
    width:465px;
}

.dashboard span.value.numeric{
    text-align: right;
    width:80px;
}

#window ul.form-flex span.value {
    display: inline-table;
    width: 230px;
}

.strong{
    font-weight:bold;
}

#window span.strong{
    font-size:1.1em;
}

#window p{
    padding:0 10px;
    margin:4px;
}

p.info-box, p.alert{
    display:block;
    font-style:italic;
    width:670px;
    padding:1em 0.5em;
    background-color:#f1f2f6;
    -moz-border-radius:8px;
    -webkit-border-radius:8px;
    border-radius:8px;
    font-size: 0.9em;
}

p.info-box .fa, p.alert .fa{
    padding-right: 1em;
}

p.alert{
    color:#D14;
}

p.info-box{
    color: #1c94c4;
}

div.form p.alert{
    background-color:#FFF;
}

#window p.info-box,
#window p.alert{
    background-color:#EEE;
    padding: 6px 16px;
    padding-left: 30px;
    width: auto;
    margin: 6px 10px;
}

#window p.alert label{
    width:650px;
}

ul.selectmulti{
    list-style-type:none;
    text-align:left;
    margin-left:100px;
}

ul.selectmulti li{
    margin:6px 0;
}

td.submit_button{
    text-align:center;
}

a.add-button, a.remove{
    padding:0 4px;
    font-weight:bold;
}

a.remove{
    margin:0 6px;
}

.dashboard .jqplot-target table{
    width:auto;
}

.dashboard table.jqplot-table-legend{
    width:default;
    border-collapse:default;
}

.dashboard div.jqplot-table-legend-swatch-outline,
.dashboard table.jqplot-table-legend th, .dashboard table.jqplot-table-legend td{
    border:0;
}

.dashboard table.jqplot-table-legend td {
    text-align:left;
    padding:0;
}

.dashboard table.resume{
    width:100%;
    border-collapse:yes;
}
.dashboard table.resume th, .dashboard table.resume td{
    border:1px solid;
}

.form table.inline-table th{
    text-align:center;
    font-weight:bold;
}

.form table.inline-table td{
    text-align:center;
}

.form table td.check{
    text-align:center;
}

.inline-table input[type=text]{
    width:60px;
}

.form p.input input.widget-parcel{
    width:50px;
}

.form p.input input.widget-oa,
input.widget-oa{
    width:100px;
}

.small, .small input{
    width:60px;
}

#progress{
    display:none;
    position:fixed;
    height:50px;
    width:100%;
    top:40%;
    z-index:42000;
}

#progress-content{
    cursor:pointer;
    background-image:url(images/ajax-loader.gif);
    background-repeat: no-repeat;
    background-position:center center;
    margin-left:auto;
    margin-right:auto;
    width:50px;
    height:50px;
    padding:10px;
}

#progress.long #progress-content{
    background-position:center 20px;
    width:130px;
    height: auto;
    padding-top: 60px;
}

#progress-content p{
    display: none;
    padding: 0;
    margin: 0;
}

#progress.long #progress-content p{
    display: block;
}

#progress.long #progress-content p.progress-detail{
    display: none;
}

#merge-table{
    background-color:#fff;
    width:700px;
}

#merge-table thead th{
    text-align:center;
    font-weight:bold;
    border-bottom:1px solid #ccc;
}

#merge-table th.small{
    width:80px;
}

/* select2 overload */

.select2-container-multi .select2-choices .select2-search-field {
    min-width:233px;
}

.select2-container-multi .select2-choices {
    border: 0 solid #FFF;
    background-color: #FFF;
    background-image: none;
}

table.table-form{
    background: #fff;
    border-collapse: collapse;
    text-align: center;
    padding: 10px 8px;
}

#window table.table-form{
    margin: 10px 80px;
}

table.table-form th {
    text-align: center;
    font-weight: normal;
    padding: 8px 6px;
    color: #922;
    border-bottom: 2px solid #922;
}

table.table-form td {
    text-align: center;
    color: #666;
    padding: 6px 15px;
}

table.table-form td input{
    border-color:#922;
}

.clean-table.small {
  width: auto;
}

.clean-table {
  margin: 10px 0 10px 0;
  width: 100%;
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.2);
}

.clean-table h4{
    color: #922;
    font-size: 1.2em;
    padding:0.3em;
    margin:0;
    text-align: center;
}

.clean-table-wrap{
  overflow: auto;
}

.clean-table table{
  width: 100%;
  border-collapse: collapse;
  margin-left: auto;
  margin-right: auto;
}

.clean-table tr {
  padding: 8px 0;
  background: #f6f6f6;
}

.clean-table tr:nth-of-type(odd) {
  background: #e9e9e9;
}

.clean-table tr th {
  font-weight: 900;
  color: #ffffff;
  background: #DA2D2D;
  text-align: center;
  padding: 0.2em 0.4em;
}

.clean-table tr th.sub {
  background: #E65C5C;
}

.clean-table td{
  text-align: right;
  padding: 6px 12px;
  box-shadow: 1px 0px 0px 0px rgba(90, 90, 90, 0.2);
}

.mini-table{
    height: 400px;
    overflow: auto;
    display: block;
}

