{% extends "base.html" %}
{% load i18n %}

{% block content %}
<div class='form'>
<form method="post" action=".">{% csrf_token %}
  <table>
  {{ form.as_table }}

  <tr><td colspan='2'><input type="submit" value="{% trans 'Submit' %}" /></td></tr>
  </table>
</form>
</p>
{% endblock %}
