{% load i18n %}{% if item %}{% if li %}<li>{% else %}<p>{% endif %}<label>{% trans caption %}{% trans ":"%}</label>
<span class='value'>{{item}}{{link}}</span>{% if li %}</li>{% else %}</p>{% endif %}
{% endif %}
