{% extends "ishtar/sheet.html" %}
{% load i18n window_tables window_header from_dict %}

{% block head_title %}{% trans "Find basket" %}{% endblock %}

{% block content %}
{% window_nav item window_id 'show-findbasket' 'select_itemsinbasket' %}
{% dynamic_table_document_large finds 'finds_for_ope' 'basket' item.pk 'TABLE_COLS_FOR_OPE' output %}
{% endblock %}
