{% extends "ishtar/wizard/confirm_wizard.html" %}
{% load i18n %}
{% block "extra_informations" %}

{% if current_object.file_responsability.count %}
<h3>{% trans "In charge of archaeological files" %}</h3>
<ul class='list'>
{% for file in current_object.file_responsability.all %}
  <li>{{file}} <a class='display_details_inline' href="#" onclick='load_window("{%url show-file file.pk ''%}")'><i class="fa fa-info-circle" aria-hidden="true"></i></a></li>{% endfor %}
</ul>
{% endif %}

{% if current_object.general_contractor.count %}
<h3>{% trans "General contractor of archaeological files" %}</h3>
<ul class='list'>
{% for file in current_object.general_contractor.all %}
  <li>{{file}} <a class='display_details_inline' href="#" onclick='load_window("{%url show-file file.pk ''%}")'><i class="fa fa-info-circle" aria-hidden="true"></i></a></li>{% endfor %}
</ul>
{% endif %}

{% if current_object.responsible_town_planning_service.count %}
<h3>{% trans "Responsible town planning service of archaeological files" %}</h3>
<ul class='list'>
{% for file in current_object.responsible_town_planning_service.all %}
  <li>{{file}} <a class='display_details_inline' href="#" onclick='load_window("{%url show-file file.pk ''%}")'><i class="fa fa-info-circle" aria-hidden="true"></i></a></li>{% endfor %}
</ul>
{% endif %}

{% if current_object.scientist.count %}
<h3>{% trans "Scientist in charge of archaeological files" %}</h3>
<ul class='list'>
{% for file in current_object.scientist.all %}
  <li>{{file}} <a class='display_details_inline' href="#" onclick='load_window("{%url show-file file.pk ''%}")'><i class="fa fa-info-circle" aria-hidden="true"></i></a></li>{% endfor %}
</ul>
{% endif %}

{% if current_object.operation_scientist_responsability.count %}
<h3>{% trans "Scientist in charge of archaeological operations" %}</h3>
<ul class='list'>
{% for operation in current_object.operation_scientist_responsability.all %}
  <li>{{operation}} <a class='display_details_inline' href="#" onclick='load_window("{%url show-operation operation.pk ''%}")'><i class="fa fa-info-circle" aria-hidden="true"></i></a></li>{% endfor %}
</ul>
{% endif %}

{% if current_object.operation_responsability.count %}
<h3>{% trans "In charge of archaeological operations" %}</h3>
<ul class='list'>
{% for operation in current_object.operation_responsability.all %}
  <li>{{operation}} <a class='display_details_inline' href="#" onclick='load_window("{%url show-operation operation.pk ''%}")'><i class="fa fa-info-circle" aria-hidden="true"></i></a></li>{% endfor %}
</ul>
{% endif %}

{% if current_object.cira_rapporteur.count %}
<h3>{% trans "Rapporteur CIRA des operations" %}</h3>
<ul class='list'>
{% for operation in current_object.cira_rapporteur.all %}
  <li>{{operation}} <a class='display_details_inline' href="#" onclick='load_window("{%url show-operation operation.pk ''%}")'><i class="fa fa-info-circle" aria-hidden="true"></i></a></li>{% endfor %}
</ul>
{% endif %}

{% if current_object.adminact_operation_in_charge.count %}
<h3>{% trans "Administrativ act: in charge of archaeological operations" %}</h3>
<ul class='list'>
{% for adminact in current_object.adminact_operation_in_charge.all %}
  <li>{{adminact}} <a class='display_details_inline' href="#" onclick='load_window("{%url show-administrativeact adminact.pk ''%}")'><i class="fa fa-info-circle" aria-hidden="true"></i></a></li>{% endfor %}
</ul>
{% endif %}

{% if current_object.adminact_scientist.count %}
<h3>{% trans "Administrativ act: scientist in charge" %}</h3>
<ul class='list'>
{% for adminact in current_object.adminact_scientist.all %}
  <li>{{adminact}} <a class='display_details_inline' href="#" onclick='load_window("{%url show-administrativeact adminact.pk ''%}")'><i class="fa fa-info-circle" aria-hidden="true"></i></a></li>{% endfor %}
</ul>
{% endif %}

{% if current_object.signatory.count %}
<h3>{% trans "Administrativ act: signatory" %}</h3>
<ul class='list'>
{% for adminact in current_object.signatory.all %}
  <li>{{adminact}} <a class='display_details_inline' href="#" onclick='load_window("{%url show-administrativeact adminact.pk ''%}")'><i class="fa fa-info-circle" aria-hidden="true"></i></a></li>{% endfor %}
</ul>
{% endif %}

{% if current_object.warehouse_in_charge.count %}
<h3>{% trans "In charge of warehouses" %}</h3>
<ul class='list'>
{% for warehouse in current_object.warehouse_in_charge.all %}
  <li>{{warehouse}}</li>{% endfor %}
</ul>
{% endif %}

{% if current_object.treatments.count %}
<h3>{% trans "Treatments of items" %}</h3>
<ul class='list'>
{% for treatments in current_object.treatments.all %}
  {% if treatment.downstream_treatment %}
  <li>{{treatment.downstream_treatment}} ({% trans "downstream"%}) <a class='display_details_inline' href="#" onclick='load_window("{%url show-item treatment.downstream_treatment ''%}")'><i class="fa fa-info-circle" aria-hidden="true"></i></a></li>
  {% endif %}
  {% if treatment.upstream_treatment %}
  <li>{{treatment.upstream_treatment}} ({% trans "upstream"%}) <a class='display_details_inline' href="#" onclick='load_window("{%url show-find treatment.upstream_treatment ''%}")'><i class="fa fa-info-circle" aria-hidden="true"></i></a></li>
  {% endif %}
{% endfor %}
</ul>
{% endif %}

{% if current_object.properties.count %}
<h3>{% trans "Property of items" %}</h3>
<ul class='list'>
{% for property in current_object.properties.all %}
  <li>{{property.find}} <a class='display_details_inline' href="#" onclick='load_window("{%url show-find property.find.pk ''%}")'><i class="fa fa-info-circle" aria-hidden="true"></i></a></li>{% endfor %}
</ul>
{% endif %}

{% if current_object.parcel_owner.count %}
<h3>{% trans "Owns parcels" %}</h3>
<ul class='list'>
{% for parcel in current_object.parcel_owner.all %}
  <li>{{parcel}}</li>{% endfor %}
</ul>
{% endif %}

{% if current_object.author.count %}
<h3>{% trans "Author" %}</h3>
<ul class='list'>
{% for author in current_object.author.all %}
  <li>{{author}}</li>{% endfor %}
</ul>
{% endif %}

{% endblock %}
