{% extends "ishtar/wizard/confirm_wizard.html" %}
{% load i18n %}

{% block "extra_informations" %}
{% if current_object.index %}
<p class='alert'><i class="fa fa-exclamation-triangle" aria-hidden="true"></i> <label>{%trans "This act is indexed!"%}</label></p>
{% endif %}
{% endblock %}
