{% extends "ishtar/sheet_source.html" %}
{% load i18n window_field window_header link_to_window %}

{% block head_title %}{% trans "Operation source" %}{% endblock %}

{% block window_nav %}
{% window_nav item window_id 'show-operationsource' 'operation_source_modify' %}
{% endblock %}

{% block related %}
{% field "Related operation" item.owner '' item.owner|link_to_window %}
{% endblock %}
