{% extends "base.html" %}Q
{% load i18n %}
{% block extra_head %}
{{search_form.media}}
{{ template_form.media }}
{% endblock %}

{% block content %}
<h2>{% trans "Document generation" %}</h2>
<form action="." method="post">{% csrf_token %}
<div class='form'>
<table>
{{ search_form.as_p }}
</table>
<h4>{% trans "Choose the type of document" %}</h4>
<table>
{{ template_form }}
</table>
<input type="submit" id="submit_form" name='validate' value="{% trans "Generate" %}"/>
</div>
</form>
{% endblock %}

