{% extends "ishtar/wizard/wizard_done.html" %}
{% load i18n %}
{% block content %}

<div class='form'>
  <p>{% trans "You have entered the following informations:" %}</p>
  {% for form_label, form_data in datas %}
  <table class='confirm'>
    <caption>{{form_label}}</caption>
    {% for label, data, cls in form_data %}
    <tr{%if cls%} class='{{cls}}'{%endif%}><th>{{label}}</th><td>{{data}}</td></th>
    {% endfor %}
  </table>
  {% endfor %}
  <p>{% trans {%trans "Item successfully saved"%} %}</p>
</div>

{% endblock %}
