{% extends "ishtar/blocks/window_nav.html" %}
{% load i18n %}
{% load url from future %}
{% block extra_actions %}
<a class='history-nav' href='{% url "operation_add" item.pk %}'>
  <span class="fa-stack fa-lg">
    <i class="fa fa-circle fa-stack-2x"></i>
    <i class="fa fa-plus fa-stack-1x fa-inverse"></i>
  </span>
  <br/>{%trans "Add an operation for this file" %}
</a>
{% endblock %}
